# Ocyan Plugin Wagtail

## Installation
-------------
Add `ocyan.plugin.wagtail` to your projects dependencies.

## Usage
-------------
It adds wagtail to the site and gives the ability of managing the content using this cms after adding "/admin" after the site url.
It adds site-settings to the wagtail-admin settings tab.
It has a custom PluginConfig: 'BlockPluginConfig', look at 'block_plugin.py'

## Configuration
Settings you need to configure in .json

* wagtailuserbar_position
    * Wagtail userbar position at the website pages when you're logged in.
* open_external_richtext_links_in_new_window
    * If you set this to True, external links will open in a new window. You can also set this in your settings through "OPEN_EXTERNAL_RICHTEXT_LINKS_IN_NEW_WINDOW"


Example: 

```json
    "wagtail": {
      "wagtailuserbar_position": "bottom-right",
      "open_external_richtext_links_in_new_window": true
    },
```